@@ -3,6 +3,7 @@ from typing import Dict, IO, Any, AnyStr, Union
 from pathlib import Path
 import sys
 import re
+import os
 
 from bml import bss
 from bml import bml
@@ -17,6 +18,8 @@ __all__ = ['bss2bml', 'main']
 SEAT_DICT = {v: k for k, v in bss.SEAT_DICT.items()}
 VUL_DICT = {v: k for k, v in bss.VUL_DICT.items()}
 
+EXTENSION = '.bml'
+
 
 class BssFile:
     # Class variable
@@ -584,6 +587,8 @@ def bss2bml(input_spec: FileSpec, output_spec: FileSpec) -> None:
         if output_spec == '-':
             output = sys.stdout
         elif isinstance(output_spec, (str, bytes, Path)):
+            if os.path.isdir(str(output_spec)):
+                output_spec = os.path.join(str(output_spec), os.path.basename(re.sub(r'\..+\Z', '.bml', str(input_spec))))
             output = open(output_spec, mode='w', encoding="utf-8")
         else:
             assert "ERROR: unknown file type for %r" % (output_spec)
@@ -601,7 +606,7 @@ def bss2bml(input_spec: FileSpec, output_spec: FileSpec) -> None:
 
 
 def main():
-    bml.args = bml.parse_arguments(description='Convert BSS to BML.', option_tree=False, option_include_external_files=False, option_indentation=False, output_extension='.bml')
+    bml.args = bml.parse_arguments(description='Convert BSS to BML.', option_tree=False, option_include_external_files=False, option_indentation=False, output_extension=EXTENSION)
     bss2bml(bml.args.inputfile, bml.args.outputfile)
 
 
